<?php
/**
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 */

if (!function_exists('kable_entry_footer')) :
    /**
     * Prints HTML with meta information for the categories, tags.
     *
     * Create your own kable_entry_meta() function to override in a child theme.
     *
     */
    function kable_entry_footer()
    {
        $social_shear = kable_get_option_data('blog_single_social_share', false);
        $archive_layout_style = kable_get_option_data('optn_archive_display_type', 'default');
        $tags_list = get_the_tag_list('',  '  ');
        ?>
        <?php
        if ($tags_list) {
            printf('<span class="entry-cat"><span class="meta-title">' . esc_html__('Tags: ', 'kable') . '</span>%1$s</span>', $tags_list);
        }
        do_action('kable_post_share');
    }
endif; //end entry footer

if (!function_exists('kable_prev_next_link')) :
    /**
     * Prints HTML with meta information for the categories, tags.
     *
     */
    function kable_prev_next_link()
    {
        ?>
        <div class="d_flex justify-content-between next">
            <?php
            previous_post_link('%link', esc_html__('Previous Post', 'kable'), TRUE);
            next_post_link('%link', esc_html__('Next Post', 'kable'), TRUE);
            ?>
        </div>
    <?php
}
endif; //end prev next

if (!function_exists('kable_grid_blog_meta')) :
    /**
     * Prints HTML with meta information for the categories, tags.
     *
     */
    function kable_grid_blog_meta()
    {

        $categories_list = get_the_category_list(', ');
        ?>
        <div class="meta-wrap t_cate">
            <?php
            if ($categories_list) {
                printf('<span class="entry-cat">%1$s</span>', $categories_list);
            }
            ?>
        </div>
    <?php

}
endif; //end grid blog meta

if (!function_exists('kable_entry_date')) :
    /**
     * Prints HTML with date information for current post.
     *
     * Create your own kable_entry_date() function to override in a child theme.
     *
     */
    function kable_entry_date()
    {
        $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

        if (get_the_time('U') !== get_the_modified_time('U')) {
            $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" style="display:none" datetime="%3$s">%4$s</time>';
        }

        $time_string = sprintf(
            $time_string,
            esc_attr(get_the_date('c')),
            get_the_date(),
            esc_attr(get_the_modified_date('c')),
            get_the_modified_date()
        );

        printf(
            '<span class="posted-on"><span class="screen-reader-text">%1$s </span><a href="%2$s" rel="bookmark">%3$s</a></span>',
            esc_html(_x('Posted on', 'Used before publish date.', 'kable')),
            esc_url(get_permalink()),
            $time_string
        );
    }
endif;

if (!function_exists('kable_entry_header')) :
    /**
     * entry header blog list.
     */
    function kable_entry_header()
    {
        ?>
        <?php if ('post' === get_post_type()) : ?>
            <div class="d_flex justify-content-center align-items-center">
                <?php the_title(sprintf('<h3 class="entry-title"><a href="%s" rel="bookmark">', esc_url(get_permalink())), '</a></h3>');  ?>
            </div>
        <?php endif;
}
endif; //kable_entry_header


if (!function_exists('kable_read_more_link')) {
    function kable_read_more_link($more_link_text = null,  $strip_teaser = false)
    {
        global $kable, $page, $more, $preview, $pages, $multipage;
        $read_more_text = isset($kable['opt_blog_continue_reading']) ? sanitize_text_field($kable['opt_blog_continue_reading']) : esc_html__('Read More', 'kable');
        if ($read_more_text == '') {
            return;
        }
        $post = get_post();

        if (null === $more_link_text) {
            $more_link_text = sprintf(
                '<span aria-label="%1$s">%2$s</span>',
                sprintf(
                    /* translators: %s: Name of current post */
                    $read_more_text,
                    the_title_attribute(array('echo' => false))
                ),
                $read_more_text
            );
        }

        $output = '';

        if ($page > $pages) // if the requested page doesn't exist
            $page =  $pages; // give them the highest numbered page that DOES exist

        $content = $pages[$page - 1];
        if (preg_match('/<!--more(.*?)?-->/', $content, $matches)) {
            $content = explode($matches[0], $content, 2);
            if (!empty($matches[1]) && !empty($more_link_text))
                $more_link_text = strip_tags(wp_kses_no_null(trim($matches[1])));
        }

        if ($content  > 1) {
            if (!empty($more_link_text))

                /**
                 * Filters the Read More link text.
                 *
                 * @since 2.8.0
                 *
                 * @param string $more_link_element Read More link element.
                 * @param string $more_link_text    Read More text.
                 */
                $output .= '<a href="' . get_permalink() . '#more-' . esc_attr($post->ID) . '" class="read_more">' . esc_attr($read_more_text) . '</a>';
        } else {
            $output .= '<a href="' . get_permalink() . '" class="read_more">' . esc_attr($read_more_text) . '</a>';
        }

        if ($preview) // Preview fix for JavaScript bug with foreign languages.
            $output =    preg_replace_callback('/\%u([0-9A-F]{4})/', '_convert_urlencoded_to_entities', $output);

        return $output;
    }
    add_filter('the_content_more_link', 'kable_read_more_link');
}
if (!function_exists('kable_default_entry_header_meta_bottom')) {
    function kable_default_entry_header_meta_bottom()
    {
        $categories_list = get_the_category_list(' ');
        ?>
        <div class="d_flex justify-content-center align-items-center meta-wrap">
            <?php
            if (is_sticky() && is_home() && !is_paged()) {
                printf('<span class="sticky-post">%s</span>', esc_html__('Featured', 'kable'));
            }
            if (has_post_format('quote')) {
                printf('<span class="sticky-post">%s</span>', esc_html__('Quote', 'kable'));
            }
            if (has_post_format('link')) {
                printf('<span class="sticky-post">%s</span>', esc_html__('Link', 'kable'));
            }
            ?>

            <span><?php kable_entry_date(); ?> </span>
            <?php
            if ($categories_list) {
                printf('<span class="entry-cat">%1$s</span>', $categories_list);
            }
            ?>
        </div>
    <?php
}
}

if (!function_exists('kable_remove_vc_from_excerpt')) {
    function kable_remove_vc_from_excerpt($excerpt)
    {
        $patterns = "/\[[\/]?vc_[^\]]*\]/";
        $replacements = "";
        return preg_replace($patterns, $replacements, $excerpt);
    }
}
if (!function_exists('kable_trim_word')) {
    function kable_trim_word($charlength)
    {
        global $word_count, $post;
        $word_count = isset($word_count) && $word_count != "" ? $word_count : $charlength;
        $post_excerpt = $post->post_excerpt != "" ? $post->post_excerpt : strip_tags($post->post_content);
        $clean_excerpt = strpos($post_excerpt, '...') ? strstr($post_excerpt, '...', true) : $post_excerpt;
        $clean_excerpt = strip_shortcodes(kable_remove_vc_from_excerpt($clean_excerpt));
        $excerpt_word_array = explode(' ', $clean_excerpt);
        $excerpt_word_array = array_slice($excerpt_word_array, 0, $word_count);
        $excerpt = implode(' ', $excerpt_word_array) . '...';
        echo '' . $excerpt . '';
    }
}


/**
 * Determines whether blog/site has more than one category.
 *
 * Create your own kable_categorized_blog() function to override in a child theme.
 *
 * @return bool True if there is more than one category, false otherwise.
 */
function kable_categorized_blog()
{
    if (false === ($all_the_cool_cats = get_transient('kable_categories'))) {
        // Create an array of all the categories that are attached to posts.
        $all_the_cool_cats = get_categories(array(
            'fields'     => 'ids',
            // We only need to know if there is more than one category.
            'number'     => 2,
        ));

        // Count the number of categories that are attached to the posts.
        $all_the_cool_cats = count($all_the_cool_cats);

        set_transient('kable_categories', $all_the_cool_cats);
    }

    if ($all_the_cool_cats > 1) {
        // This blog has more than 1 category so kable_categorized_blog should return true.
        return true;
    } else {
        // This blog has only 1 category so kable_categorized_blog should return false.
        return false;
    }
}

/**
 * Flushes out the transients used in kable_categorized_blog().
 *
 * @since kable
 */
function kable_category_transient_flusher()
{
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    // Like, beat it. Dig?
    delete_transient('kable_categories');
}
add_action('edit_category', 'kable_category_transient_flusher');
add_action('save_post',     'kable_category_transient_flusher');


if (!function_exists('kable_custom_post_prev_next_link')) :
    /**
     * custom post pagination
     *
     */
    function kable_custom_post_prev_next_link($post_type_name = '')
    {
        ?>
        <div class="next_prev_buttons d_flex justify-content-between align-items-center mt70">
            <?php
            $prev_post = get_previous_post();
            if ($prev_post) {
                $prev_title = strip_tags(str_replace('"', '', $prev_post->post_title));
                echo "\t" . '<a rel="prev" href="' . get_permalink($prev_post->ID) . '" title="' . $prev_title . '">&larr;</a>' . "\n";
            } else {
                echo '<span></span>';
            }
            echo "\t" . '<a href="' . get_post_type_archive_link($post_type_name) . '">&#8759;</a>' . "\n";

            $next_post = get_next_post();
            if ($next_post) {
                $next_title = strip_tags(str_replace('"', '', $next_post->post_title));
                echo "\t" . '<a rel="next" href="' . get_permalink($next_post->ID) . '" title="' . $next_title . '">&rarr;</a>' . "\n";
            } else {
                echo '<span></span>';
            }
            ?>
        </div>
    <?php
}
endif; //end custom prev next


if (!function_exists('kable_pingback_header')) {
    function kable_pingback_header()
    {
        if (is_singular() && pings_open()) {
            echo '<link rel="pingback" href="', esc_url(get_bloginfo('pingback_url')), '">';
        }
    }
    add_action('wp_head', 'kable_pingback_header');
}
