<?php
$prefix = 'kable_';
$thumbnail = get_post_meta(get_the_ID(), $prefix . 'single_products_thumbnail', true);

/*
 * woocommerce core function
 */

if (!function_exists('kable_header_add_to_cart_fragment')) {

    /**
     * woocommerce action
     * */
    function kable_header_add_to_cart_fragment($fragments)
    {
        ob_start();
        $count = WC()->cart->cart_contents_count;
        ?><span class="cart-items"><?php echo esc_attr($count); ?></span>
        <?php
        $fragments['span.cart-items'] = ob_get_clean();

        return $fragments;
    }

    add_filter('woocommerce_add_to_cart_fragments', 'kable_header_add_to_cart_fragment');
}

if (!function_exists('kable_cart_total')) {

    function kable_cart_total()
    {
        global $woocommerce;
        ?>
        <span class="shop-text"><span class="total"><?php echo esc_html($woocommerce->cart->get_cart_subtotal()); ?></span></span>
    <?php
    }
}

if (!function_exists('kable_cart_number')) {

    function kable_cart_number()
    {
        global $woocommerce;
        ?>
        <span class="badge-number" data-items-count="<?php echo esc_attr($woocommerce->cart->cart_contents_count); ?>"><?php echo esc_html($woocommerce->cart->cart_contents_count); ?></span>
    <?php
    }
}

if (!function_exists('kable_get_fragments')) {
    add_filter('woocommerce_add_to_cart_fragments', 'kable_get_fragments', 30);

    function kable_get_fragments($array = array())
    {
        ob_start();
        kable_cart_total();
        $cart_total = ob_get_clean();

        ob_start();
        kable_cart_number();
        $cart_number = ob_get_clean();


        $array['span.shop-text'] = $cart_total;
        $array['span.badge-number'] = $cart_number;

        return $array;
    }
}
if (!function_exists('kable_quick_view_button')) {

    function kable_quick_view_button()
    {
        global $post;
        echo '<a class="product-label quickview" href="javascript:void(0);" data-product-id="' . esc_attr($post->ID) . '">' . esc_html__('Quick View', 'kable') . '</a>';
    }
}

if (!function_exists('kable_wc_template_loop_product_thumbnail')) {

    function kable_wc_template_loop_product_thumbnail()
    {
        /**
         * woocommerce product thumbnail
         * */
        global $post, $product, $woocommerce_loop;

        $column = kable_get_option_data('optn_woo_products_per_row', 3);
        $fitRows = kable_get_option_data('product_layout_mode', 'fitRows');


        $img_count = 0;
        $attachment_ids = $product->get_gallery_image_ids();
        $product_img = kable_get_option_data('optn_product_image_type', 'none');


        if ($fitRows == 'masonry') {
            $post_thumbnail_id = get_post_thumbnail_id(get_the_ID());
            $arrImages = wp_get_attachment_image_src($post_thumbnail_id, 'full');

            $matrix = array(
                '3' => array(
                    array(2, 1, 2),
                    array(2, 1, 1)
                ),
                '4' => array(
                    array(1, 2, 1, 2),
                    array(2, 2, 2, 1),
                    array(1, 2, 2, 1),
                ),
                '5' => array(
                    array(1, 2, 1, 2, 1),
                    array(2, 2, 2, 1, 1),
                )
            );

            $index_row = floor(($woocommerce_loop['loop'] - 1) / $column) % 2;
            $index_col = ($woocommerce_loop['loop'] - 1) % $column;

            $width = 303;
            $height = 450;

            if ($matrix[$column][$index_row][$index_col] == 1) {
                $width = 303;
                $height = 244;
            }

            $thumbnail_url = '';
            if (count($arrImages) > 0) {
                $resize = matthewruddy_image_resize($arrImages[0], $width, $height);
                if ($resize != null && is_array($resize))
                    $thumbnail_url = $resize['url'];
            }
        } else {
            $image_attributes = wp_get_attachment_image_src(get_post_thumbnail_id(), 'shop_catalog');
        }
        ?>

        <?php if ($product_img == 'carousel' && $fitRows != 'masonry') : ?>
            <figure class="piko-carousel sc psh br" data-slick='{"slidesToShow": 1,"slidesToScroll": 1,}'>
                <?php
                if (has_post_thumbnail()) :
                    printf('<a href="%s"><img src="%s" srcset="%s" width="%s" height="%s" alt="%s" sizes="%s"/></a>', esc_url(get_the_permalink()), esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), '', '100vw');
                else :
                    echo wc_placeholder_img();
                endif;
                ?>
                <?php
                if ($attachment_ids) {
                    foreach ($attachment_ids as $attachment_id) {
                        if (get_post_meta($attachment_id, '_woocommerce_exclude_image', true))
                            continue;
                        $img_src = wp_get_attachment_image_src($attachment_id, 'shop_catalog');
                        printf('<a href="%s"><img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes="%s"/></a>', esc_url(get_the_permalink()), esc_url($img_src[0]), wp_get_attachment_image_srcset($attachment_id), esc_attr($img_src[1]), esc_attr($img_src[2]), 'attachment-shop_catalog size-shop_catalog', '', '100vw');
                        $img_count++;
                    }
                }
                ?>
            </figure>
        <?php elseif ($product_img == 'rollover' && $fitRows != 'masonry') : ?>
            <figure>
                <a href="<?php esc_url(the_permalink()) ?>">

                    <?php
                    if (has_post_thumbnail()) {
                        if ($attachment_ids) {
                            foreach ($attachment_ids as $attachment_id) {
                                if (get_post_meta($attachment_id, '_woocommerce_exclude_image', true))
                                    continue;
                                $img_src = wp_get_attachment_image_src($attachment_id, 'shop_catalog');
                                printf('<div class="product-image"><img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes="%s"/></div>', esc_url($img_src[0]), wp_get_attachment_image_srcset($attachment_id), esc_attr($img_src[1]), esc_attr($img_src[2]), 'attachment-shop_catalog size-shop_catalog', '', '100vw');

                                $img_count++;
                                if ($img_count == 1)
                                    break;
                            }
                            printf('<div class="product-image"><img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes="%s"/></div>', esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), 'attachment-shop_catalog size-shop_catalog', '', '100vw');
                        } else {
                            printf('<div class="product-image"><img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes="%s"/></div>', esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), 'attachment-shop_catalog size-shop_catalog', '', '100vw');
                        }
                    } else {
                        echo wc_placeholder_img();
                    }
                    ?>
                </a>
            </figure>
        <?php else : ?>
            <figure>
                <a href="<?php esc_url(the_permalink()) ?>">
                    <?php
                    if (has_post_thumbnail()) {
                        if ($fitRows == 'masonry') {
                            printf('<img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes="%s"/>', esc_url($thumbnail_url), '', esc_attr($width), esc_attr($height), 'attachment-shop_catalog size-shop_catalog', '', '100vw');
                        } else {
                            printf('<img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes="%s"/>', esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), 'attachment-shop_catalog size-shop_catalog', '', '100vw');
                        }
                    } else {
                        echo wc_placeholder_img();
                    }
                    ?>
                </a>
            </figure>
        <?php
        endif;
    }
}

if (!function_exists('kable_wc_template_loop_product_thumbnail_single')) {

    function kable_wc_template_loop_product_thumbnail_single()
    {
        /**
         * woocommerce product thumbnail
         * */
        global $post;
        $image_attributes = wp_get_attachment_image_src(get_post_thumbnail_id(), 'shop_catalog');

        kable_quick_view_button();
        ?>
        <figure>
            <a href="<?php esc_url(the_permalink()) ?>">
                <?php
                if (has_post_thumbnail()) {
                    printf('<img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes="%s"/>', esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), 'attachment-shop_catalog size-shop_catalog', '', '100vw');
                } else {
                    echo wc_placeholder_img();
                }
                ?>
            </a>
        </figure>
    <?php
    }
}
if (!function_exists('kable_wc_template_loop_product_thumbnail_rollover')) {

    function kable_wc_template_loop_product_thumbnail_rollover()
    {
        global $post, $product;
        $img_count = 0;
        $attachment_ids = $product->get_gallery_image_ids();
        $image_attributes = wp_get_attachment_image_src(get_post_thumbnail_id(), 'shop_catalog');
        ?>
        <figure>
            <a href="<?php esc_url(the_permalink()) ?>">
                <?php
                if (has_post_thumbnail()) {
                    if ($attachment_ids) {
                        foreach ($attachment_ids as $attachment_id) {
                            if (get_post_meta($attachment_id, '_woocommerce_exclude_image', true))
                                continue;
                            $img_src = wp_get_attachment_image_src($attachment_id, 'shop_catalog');
                            printf('<div class="product-image"><img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes="%s"/></div>', esc_url($img_src[0]), wp_get_attachment_image_srcset($attachment_id), esc_attr($img_src[1]), esc_attr($img_src[2]), 'attachment-shop_catalog size-shop_catalog', '', '100vw');

                            $img_count++;
                            if ($img_count == 1)
                                break;
                        }
                        printf('<div class="product-image"><img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes="%s"/></div>', esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), 'attachment-shop_catalog size-shop_catalog', '', '100vw');
                    } else {
                        printf('<div class="product-image"><img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes="%s"/></div>', esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), 'attachment-shop_catalog size-shop_catalog', '', '100vw');
                    }
                } else {
                    echo wc_placeholder_img();
                }
                ?>
            </a>
        </figure>
    <?php
        //        kable_quick_view_button();
    }
}
if (!function_exists('kable_wc_template_loop_product_thumbnail_carousel')) {

    function kable_wc_template_loop_product_thumbnail_carousel()
    {
        global $product;
        $img_count = 0;
        $attachment_ids = $product->get_gallery_image_ids();
        $image_attributes = wp_get_attachment_image_src(get_post_thumbnail_id(), 'shop_catalog');
        ?>


        <figure class="piko-carousel sc psh br" data-slick='{"slidesToShow": 1,"slidesToScroll": 1,}'>
            <?php
            if (has_post_thumbnail()) :
                printf('<a href="%s"><img src="%s" srcset="%s" width="%s" height="%s" alt="%s" sizes="%s"/></a>', esc_url(get_the_permalink()), esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), '', '100vw');
            else :
                echo wc_placeholder_img();
            endif;
            ?>
            <?php
            if ($attachment_ids) {
                foreach ($attachment_ids as $attachment_id) {
                    if (get_post_meta($attachment_id, '_woocommerce_exclude_image', true))
                        continue;
                    $img_src = wp_get_attachment_image_src($attachment_id, 'shop_catalog');
                    printf('<a href="%s"><img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes="%s"/></a>', esc_url(get_the_permalink()), esc_url($img_src[0]), wp_get_attachment_image_srcset($attachment_id), esc_attr($img_src[1]), esc_attr($img_src[2]), 'attachment-shop_catalog size-shop_catalog', '', '100vw');
                    $img_count++;
                }
            }
            ?>
        </figure>
        <?php
        kable_quick_view_button();
    }
}
//product list;

if (!function_exists('kable_wc_template_product_loop_list_start_before')) {

    function kable_wc_template_product_loop_list_start_before()
    {
        echo '<div class="d_flex"><div class="media-list">';
    }
}
if (!function_exists('kable_wc_template_product_loop_list_start_after')) {

    function kable_wc_template_product_loop_list_start_after()
    {
        echo '</div>';
    }
}
if (!function_exists('kable_wc_template_product_loop_list_end_before')) {

    function kable_wc_template_product_loop_list_end_before()
    {
        echo '<div>';
    }
}
if (!function_exists('kable_wc_template_product_loop_list_end_after')) {

    function kable_wc_template_product_loop_list_end_after()
    {
        echo '</div></div>';
    }
}


if (!function_exists('kable_wc_template_quick_view_product_thumbnail_carousel')) {

    function kable_wc_template_quick_view_product_thumbnail_carousel()
    {
        global $product;
        $img_count = 0;
        $post_id = get_the_ID();
        $attachment_ids = $product->get_gallery_image_ids();
        $image_attributes = wp_get_attachment_image_src(get_post_thumbnail_id(), array('500', '550'));
        ?>


        <figure class="piko-carousel1 piko-slick-viewport dot-in sc psh br for-<?php echo esc_attr($post_id); ?>" data-slick='{"slidesToShow": 1,"slidesToScroll": 1,"arrows":false,"dots": true, "asNavFor":".nav-<?php echo esc_attr($post_id); ?>"}'>
            <?php
            if (has_post_thumbnail()) :
                printf('<a href="%s"><img src="%s" srcset="%s" width="%s" height="%s" alt="%s" sizes="%s"/></a>', esc_url(get_the_permalink()), esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), '', '100vw');

            else :
                echo wc_placeholder_img();
            endif;
            ?>
            <?php
            if ($attachment_ids) {
                foreach ($attachment_ids as $attachment_id) {
                    if (get_post_meta($attachment_id, '_woocommerce_exclude_image', true))
                        continue;
                    $img_src = wp_get_attachment_image_src($attachment_id, array('500', '550'));
                    $img_count++;
                }
            }
            ?>
        </figure>
    <?php
    }
}
if (!function_exists('kable_wc_template_quick_view_product_thumbnail')) {

    function kable_wc_template_quick_view_product_thumbnail()
    {
        global $product;
        $img_count = 0;
        $post_id = get_the_ID();
        $attachment_ids = $product->get_gallery_image_ids();
        $image_attributes = wp_get_attachment_image_src(get_post_thumbnail_id(), array('150', '150'));
        ?>
        <div class="piko-carousel1 slick-thumb bttom sc psh br nav-<?php echo esc_attr($post_id) ?>" data-slick='{"slidesToShow": 4,"slidesToScroll": 1,"arrows":false,"focusOnSelect": true,"asNavFor":".for-<?php echo esc_attr($post_id); ?>"}'>
            <?php
            if (has_post_thumbnail()) :
                printf('<a href="%s"><img src="%s" srcset="%s" width="%s" height="%s" alt="%s" sizes=""/></a>', esc_url(get_the_permalink()), esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), '');

            else :
                echo wc_placeholder_img();
            endif;

            if ($attachment_ids) {
                foreach ($attachment_ids as $attachment_id) {
                    if (get_post_meta($attachment_id, '_woocommerce_exclude_image', true))
                        continue;
                    $img_src = wp_get_attachment_image_src($attachment_id, array('150', '150'));
                    printf('<a href="%s"><img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes=""/></a>', esc_url(get_the_permalink()), esc_url($img_src[0]), wp_get_attachment_image_srcset($attachment_id), esc_attr($img_src[1]), esc_attr($img_src[2]), 'attachment-shop_catalog size-shop_catalog', '');
                    $img_count++;
                }
            }
            ?>
        </div>
    <?php
    }
}
if (!function_exists('kable_wc_template_quick_view_product_thumbnail_vartical')) {

    function kable_wc_template_quick_view_product_thumbnail_vartical()
    {
        global $product;
        $img_count = 0;
        $post_id = get_the_ID();
        $attachment_ids = $product->get_gallery_image_ids();
        $image_attributes = wp_get_attachment_image_src(get_post_thumbnail_id(), array('150', '150'));
        $class = 'left';
        if (function_exists('election_is_mobile') && kable_is_mobile()) {
            $class = 'bottom';
        }
        ?>
        <div class="piko-carousel1 slick-thumb <?php echo esc_attr($class) ?> sc psh br nav-<?php echo esc_attr($post_id); ?>" data-slick='{"slidesToShow": 4,"slidesToScroll": 1,"vertical":true,"verticalSwiping":true,"arrows":false,"focusOnSelect": true,"asNavFor":".for-<?php echo esc_attr($post_id); ?>","responsive": [{"breakpoint": 991,"settings":{"slidesToShow":3}},{"breakpoint": 576,"settings":{"slidesToShow":4,"vertical":false,"verticalSwiping":false}}]}'>
            <?php
            if (has_post_thumbnail()) :
                printf('<a href="%s"><img src="%s" srcset="%s" width="%s" height="%s" alt="%s" sizes=""/></a>', esc_url(get_the_permalink()), esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), '');

            else :
                echo wc_placeholder_img();
            endif;
            if ($attachment_ids) {
                foreach ($attachment_ids as $attachment_id) {
                    if (get_post_meta($attachment_id, '_woocommerce_exclude_image', true))
                        continue;
                    $img_src = wp_get_attachment_image_src($attachment_id, array('150', '150'));
                    printf('<a href="%s"><img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes=""/></a>', esc_url(get_the_permalink()), esc_url($img_src[0]), wp_get_attachment_image_srcset($attachment_id), esc_attr($img_src[1]), esc_attr($img_src[2]), 'attachment-shop_catalog size-shop_catalog', '');
                    $img_count++;
                }
            }
            ?>
        </div>
    <?php
    }
}



if (!function_exists('kable_wc_template_loop_product_thumbnail_1x')) {

    function kable_wc_template_loop_product_thumbnail_1x()
    {
        /**
         * woocommerce product thumbnail 1x
         * */
        $image_attributes = wp_get_attachment_image_src(get_post_thumbnail_id(), 'thumbnail');
        ?>
        <figure>
            <a href="<?php esc_url(the_permalink()) ?>">
                <?php
                if (has_post_thumbnail()) {
                    printf('<img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes=""/>', esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), 'attachment-shop_catalog size-shop_catalog', '');
                } else {
                    echo wc_placeholder_img();
                }
                ?>
            </a>
        </figure>
    <?php
    }
}
if (!function_exists('kable_wc_template_loop_product_thumbnail_2x')) {

    function kable_wc_template_loop_product_thumbnail_2x()
    {
        /**
         * woocommerce product thumbnail 2x
         * */
        $image_attributes = wp_get_attachment_image_src(get_post_thumbnail_id(), 'shop_single');
        ?>

        <figure>
            <a href="<?php esc_url(the_permalink()) ?>">
                <?php
                if (has_post_thumbnail()) {
                    printf('<img src="%s" srcset="%s" width="%s" height="%s" class="%s" alt="%s" sizes=""/>', esc_url($image_attributes[0]), wp_get_attachment_image_srcset(get_post_thumbnail_id()), esc_attr($image_attributes[1]), esc_attr($image_attributes[2]), 'attachment-shop_catalog size-shop_catalog', '');
                } else {
                    echo wc_placeholder_img();
                }
                ?>
            </a>
        </figure>
        <?php
        if (class_exists('YITH_WCQV_Frontend')) :
            $label = get_option('yith-wcqv-button-label');
            echo '<a href="#" class="btn-quickview yith-wcqv-button" data-product_id="' . get_the_ID() . '">' . esc_html($label) . '</a>';
        endif; // YITH_WCQV_Frontend
        ?>
    <?php
    }
}

function kable_wc_template_loop_product_coundown()
{
    $id = get_the_ID();
    $time = kable_get_max_date_sale($id);
    $y = date('Y', $time);
    $m = date('m', $time);
    $d = date('d', $time);

    $sale_price_dates_from = ($date = get_post_meta($id, '_sale_price_dates_from', true)) ? date_i18n('Y-m-d', $date) : '';

    if ($sale_price_dates_from !== '') {
        ?>
        <div class="countdown-lastest" data-y="<?php echo esc_attr($y); ?>" data-m="<?php echo esc_attr($m); ?>" data-d="<?php echo esc_attr($d); ?>" data-h="00" data-i="00" data-s="00"></div>
    <?php
    }
}

function kable_wc_template_loop_product_cat_rating()
{
    global $product;
    $excerpt = kable_get_option_data('product_list_excerpt', '25');
    $product_layout = kable_get_option_data('optn_woo_archive_products_layout', '1');
    ?>
    <div class="product-middle d_flex flex-column align-items-center justify-content-center">
        <div class="title-wrap">
            <?php kable_wc_template_loop_product_title(); ?>
            <?php if (is_shop() || is_product_category()) : ?>
                <div class="list-content"><?php echo wp_trim_words(get_the_excerpt(), esc_attr($excerpt), ' ... '); ?></div>
            <?php endif; ?>
        </div>
        <div class="btn-action">
            <span class="price"><?php echo wp_kses_post($product->get_price_html()); ?></span>
            <?php
            if ($product_layout === '2') :
                kable_wc_template_loop_product_thumbnail_button_action_two();
            endif;
            ?>

        </div>
    </div>
<?php
}

$mode_view = apply_filters('kable_filter_products_mode_view', 'grid');
$product_layout = kable_get_option_data('optn_woo_archive_products_layout', '1');
if ($product_layout == '2' && $mode_view == 'grid') {
    remove_action('woocommerce_before_shop_loop_item_title', 'kable_wc_template_loop_product_thumbnail_button_action', 11);
    add_action('woocommerce_before_shop_loop_item_title', 'kable_wc_template_loop_product_thumbnail_button_action_two_thumbnail', 11);
}

if (!function_exists('kable_wc_template_loop_add_to_cart')) {

    /**
     * Get the add to cart template for the loop.
     *
     * @param array $args Arguments.
     */
    function kable_wc_template_loop_add_to_cart($args = array())
    {
        global $product;

        if ($product) {
            $ajax_class = '';
            if ('yes' === get_option('woocommerce_enable_ajax_add_to_cart')) {
                $ajax_class =  $product->supports('ajax_add_to_cart') ? 'ajax_add_to_cart' : '';
            }

            $defaults = array(
                'quantity' => 1,
                'class' => implode(' ', array_filter(array(
                    'button btn-ac',
                    'product_type_' . $product->get_type(),
                    $product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
                    $ajax_class,
                ))),
                'attributes' => array(
                    'data-product_id' => $product->get_id(),
                    'data-product_sku' => $product->get_sku(),
                    'aria-label' => $product->add_to_cart_description(),
                    'rel' => 'nofollow',
                ),
            );

            $args = apply_filters('woocommerce_loop_add_to_cart_args', wp_parse_args($args, $defaults), $product);

            if (isset($args['attributes']['aria-label'])) {
                $args['attributes']['aria-label'] = strip_tags($args['attributes']['aria-label']);
            }

            wc_get_template('loop/add-to-cart.php', $args);
        }
    }
}

function kable_wc_template_loop_product_title()
{
    ?>
    <h3 class="product-title">
        <a href="<?php esc_url(the_permalink()) ?>"><?php the_title(); ?></a>
    </h3>
<?php
}

function kable_wc_template_loop_product_price()
{
    global $product;
    $cart_btn = kable_get_option_data('catalog_mode', '1');
    ?>
    <div class="d_flex align-items-center justify-content-between btn-action">
        <span class="price <?php
                            if (!$cart_btn) {
                                echo 'pt5 pb10';
                            }
                            ?>"><?php echo wp_kses_post($product->get_price_html()); ?></span>
        <?php
        //if($cart_btn){ woocommerce_template_loop_add_to_cart();}

        kable_wc_template_loop_product_rating();
        ?>

    </div><!-- End .product-price-container -->
<?php
}

function kable_wc_template_loop_product_rating()
{
    global $product;

    $rating_count = $product->get_rating_count();
    $review_count = $product->get_review_count();
    $average = $product->get_average_rating();

    if (get_option('woocommerce_enable_review_rating') === 'yes' && !$review_count) {
        return;
    }
    ?>

    <?php if ($rating_count > 0) : ?>
        <div class="star-rating" title="<?php printf(esc_attr__('Rated %s out of 5', 'kable'), $average); ?>">
            <span style="width:<?php echo ((esc_html($average) / 5) * 100); ?>%">
                <strong class="rating"><?php echo esc_html($average); ?></strong> <?php printf(esc_html__('out of %s5%s', 'kable'), '<span>', '</span>'); ?>
                <?php printf(esc_html(_n('based on %s customer rating', 'based on %s customer ratings', $rating_count, 'kable')), '<span class="rating">' . esc_html($rating_count) . '</span>'); ?>
            </span>
        </div>
    <?php endif; ?>
    <?php
    if (is_product() && $review_count > 0) {
        /* translators: 1: reviews count 2: product name */
        echo '<div class="product-ratings-desc">';
        printf(esc_html(_n(' %1$s review', '%1$s review&#40;s&#41;', $review_count, 'kable')), esc_html($review_count));
        echo '</div>';
    }
}


function kable_wc_template_loop_product_button_action()
{
    ?>
    <div class="btn-action other d_flex align-items-center justify-content-center">
        <?php
        echo kable_wc_wishlist_button();
        do_action('kable_wc_loop_product_bottom');
        ?>
    </div><!-- End .product-action -->
<?php
}

function kable_wc_template_loop_product_thumbnail_button_action()
{ //new button action
    global $post;
    $cart_btn = kable_get_option_data('catalog_mode', 0);
    $product_layout = kable_get_option_data('optn_woo_archive_products_layout', '1');
    ?>
    <div class="thumb_action pa t_c">

        <?php
        if ($product_layout == '2') {
            if ($cart_btn == 0 && kable_is_compare_activated() ==  true) {
                echo '<a class="btn-ac quickview" href="javascript:void(0);" data-product-id="' . esc_attr($post->ID) . '"><span class="fa fa-eye"></span></a>';
            }
            echo kable_wc_wishlist_button();
        } else {
            do_action('kable_wc_loop_product_bottom');
            echo '<a class="btn-ac quickview" href="javascript:void(0);" data-product-id="' . esc_attr($post->ID) . '"><span class="fa fa-eye"></span></a>';
            echo kable_wc_wishlist_button();
            if ($cart_btn == 0) {
                kable_wc_template_loop_add_to_cart();
            }
        }

        ?>
    </div><!-- End .product-action -->
<?php
}
function kable_wc_template_loop_product_thumbnail_button_action_two()
{ //new button action
    global $post;
    $cart_btn = kable_get_option_data('catalog_mode', 0);
    ?>
    <div class="action_bottom d_flex align-items-center justify-content-between">

        <?php
        if (kable_is_compare_activated() ==  true) {
            kable_add_to_compare_link();
        }
        if ($cart_btn == 1 && kable_is_compare_activated() ==  true || $cart_btn == 0 &&  kable_is_compare_activated() ==  false) {
            echo '<a class="btn-ac quickview" href="javascript:void(0);" data-product-id="' . esc_attr($post->ID) . '"><span class="fa fa-eye"></span>' . esc_html__('Quick View', 'kable') . '</a>';
        }
        if ($cart_btn == 0) {
            kable_wc_template_loop_add_to_cart();
        }
        ?>
    </div><!-- End .product-action -->
<?php
}
function kable_wc_wishlist_button()
{
    global $product, $yith_wcwl;

    if (!class_exists('YITH_WCWL'))
        return;

    $url = YITH_WCWL()->get_wishlist_url();
    $product_type = $product->get_type();
    $exists = $yith_wcwl->is_product_in_wishlist($product->get_id());
    $classes = 'class="add_to_wishlist"';
    $add = get_option('yith_wcwl_add_to_wishlist_text');
    $browse = get_option('yith_wcwl_browse_wishlist_text');
    $added = get_option('yith_wcwl_product_added_text');

    $add = $browse = $added = $output = '';

    $output .= '<div class="btn-ac yith-wcwl-add-to-wishlist pr add-to-wishlist-' . esc_attr($product->get_id()) . '">';
    $output .= '<div class="yith-wcwl-add-button';
    $output .= $exists ? ' hide" style="display:none;"' : ' show"';
    $output .= '><i class="fa fa-spinner fa-pulse ajax-loading pa" style="visibility:hidden"></i><a href="' . esc_url(htmlspecialchars(YITH_WCWL()->get_wishlist_url())) . '" data-product-id="' . esc_attr($product->get_id()) . '" data-product-type="' . esc_attr($product_type) . '" ' . $classes . ' ><i class="fa fa-heart-o"></i>' . esc_attr($add) . '</a>';
    $output .= '';
    $output .= '</div>';

    $output .= '<div class="yith-wcwl-wishlistaddedbrowse hide" style="display:none;"><a href="' . esc_url($url) . '"><i class="fa fa-heart"></i>' . esc_attr($browse) . '</a></div>';
    $output .= '<div class="yith-wcwl-wishlistexistsbrowse ' . ($exists ? 'show' : 'hide') . '" style="display:' . ($exists ? 'block' : 'none') . '"><a href="' . esc_url($url) . '" ><i class="la la-check"></i>' . esc_attr($added) . '</a></div>';
    $output .= '</div>';

    return $output;
}

function kable_wc_quickview()
{
    // Get product from request.
    if (isset($_POST['product']) && (int) $_POST['product']) {
        global $post, $product, $woocommerce;

        $id = (int) $_POST['product'];
        $post = get_post($id);
        $product = get_product($id);

        if ($product) {
            // Get quickview template.
            include KABLE_THEME_DIR . '/woocommerce/content-quickview-product.php';
        }
    }

    exit;
}

add_action('wp_ajax_piko_quickview', 'kable_wc_quickview');
add_action('wp_ajax_nopriv_piko_quickview', 'kable_wc_quickview');

//single product
function kable_wc_template_single_product_miscellaneous()
{
    if (get_post_type(get_the_ID()) == 'product' && is_singular() && !is_page()) :
        $enable_miscellaneous = kable_get_option_data('enable_miscellaneous', '0');
        $guide_title = kable_get_option_data('size_guide_title', '');

        $size_guide_id = get_post_meta(get_the_ID(), 'kable_size_guide', true);
        $size_guide['url'] = wp_get_attachment_image_url($size_guide_id, '') ? wp_get_attachment_image_url($size_guide_id, '') : '';
        if (!isset($size_guide['url']) || $size_guide['url'] == '') {
            $size_guide = kable_get_option_data('size_guide', '');
        }

        $policy_title = kable_get_option_data('return_policy_title', '');
        $return_policy = kable_get_option_data('return_policy', '');
        ?>
        <?php if ($enable_miscellaneous == '1') : ?>
            <div class="guide-wrap d_flex mb10 f_w6">
                <?php
                if (!empty($size_guide['url'])) {
                    echo '<a class="piko-lightbox-single" href="' . esc_url($size_guide['url']) . '">' . esc_attr($guide_title) . '</a>';
                }
                if (!empty($return_policy)) {
                    echo '<a class="return-policy" href="#">' . esc_attr($policy_title) . '</a>';
                }
                ?>
            </div>
        <?php
        endif; //$enable_miscellaneous
    endif; //post type
}

function kable_wc_shipping_terms()
{
    // Get shipiping content single page
    $return_policy = kable_get_option_data('return_policy', '');
    if (!$return_policy)
        return;

    $output = '<div class="return-content">' . $return_policy . '</div>';

    echo wp_kses_post($output);
    exit;
}

add_action('wp_ajax_jas_piko_shipping_terms', 'kable_wc_shipping_terms');
add_action('wp_ajax_nopriv_piko_shipping_terms', 'kable_wc_shipping_terms');

function kable_wc_template_cart_page_product_code($sku)
{
    global $product;

    if (wc_product_sku_enabled() && ($product->get_sku() || $product->is_type('variable'))) : ($sku = $product->get_sku()) ? esc_attr($sku) : esc_attr__('N/A', 'kable');
        return;
    endif;
}

function kable_wc_template_single_product_button_action()
{
    echo kable_wc_wishlist_button();
}

function kable_wc_template_loop_price_deals()
{
    global $product;
    ?>
    <footer class="product-footer">
        <span class="price"><?php echo wp_kses_post($product->get_price_html()); ?></span>
        <div class="clearfix"></div>
    </footer>
<?php
}

if (!function_exists('kable_woocommerce_custom_sales_price')) {

    /**
     * Sale price Percentage
     */
    function kable_woocommerce_custom_sales_price($product)
    {

        global $post, $product;
        if (!$product->is_in_stock() || $product->is_type('grouped'))
            return;
        $sale_price = get_post_meta($product->get_id(), '_price', true);
        $regular_price = get_post_meta($product->get_id(), '_regular_price', true);
        if (empty($regular_price)) { //then this is a variable product
            $available_variations = $product->get_available_variations();
            $variation_id = $available_variations[0]['variation_id'];
            $variation = new WC_Product_Variation($variation_id);
            $regular_price = $variation->get_regular_price();
            $sale_price = $variation->get_sale_price();
            if (empty($sale_price)) {
                $variation_id = $available_variations[1]['variation_id'];
                $variation = new WC_Product_Variation($variation_id);
                $sale_price = $variation->get_sale_price();
            }
        }
        $percentage = ceil((($regular_price - $sale_price) / $regular_price) * 100);
        if (!empty($regular_price) && !empty($sale_price) && $regular_price > $sale_price) :
            return sprintf('<span class="product-label discount">-%1$s</span>', esc_attr($percentage) . esc_attr__('%', 'kable'), $post, $product);
        endif;
    }

    add_filter('woocommerce_sale_flash', 'kable_woocommerce_custom_sales_price');
}





if (!function_exists('woocommerce_enable_review_rating')) { //m-n-u
    /**
     * comment rating
     */

    function kable_wc_template_loop_rating()
    {

        global $product;

        if (get_option('woocommerce_enable_review_rating') === 'no') {
            return;
        }

        $rating_count = $product->get_rating_count();
        $review_count = $product->get_review_count();
        $average = $product->get_average_rating();
        ?>

        <?php if ($rating_count > 0) : ?>
            <div class="star-rating" title="<?php printf(esc_attr__('Rated %s out of 5', 'kable'), esc_html($average)); ?>">
                <span style="width:<?php echo ((esc_html($average) / 5) * 100); ?>%">
                    <strong itemprop="ratingValue" class="rating"><?php echo esc_html($average); ?></strong> <?php printf(esc_html__('out of %s5%s', 'kable'), '<span itemprop="bestRating">', '</span>'); ?>
                    <?php printf(esc_html(_n('based on %s customer rating', 'based on %s customer ratings', $rating_count, 'kable')), '<span itemprop="ratingCount" class="rating">' . esc_attr($rating_count) . '</span>'); ?>
                </span>
            </div>
        <?php endif; ?>
        <div class="clearfix"></div>
    <?php
    }
}

if (!function_exists('woocommerce_enable_review_rating_numeric')) { //m-n-u
    /**
     * comment count
     */

    function woocommerce_enable_review_rating_numeric()
    {

        global $product;
        if (get_option('woocommerce_enable_review_rating') === 'no') {
            return;
        }

        $rating_count = $product->get_rating_count();
        $review_count = $product->get_review_count();
        $average = $product->get_average_rating();

        if ($rating_count > 0) :
            ?>
            <div class="single-rating" title="<?php printf(esc_attr__('Rated %s out of 5', 'kable'), esc_html($average)); ?>">
                <i class="fa fa-star-o" aria-hidden="true"></i>
                <span><?php echo esc_html(_n('%s', '%s', $average, 'kable')) . esc_html__('/5', 'kable'); ?></span>
            </div>
        <?php
        endif;
    }
}

add_filter('woocommerce_breadcrumb_defaults', 'kable_woo_breadcrumbs');

function kable_woo_breadcrumbs()
{
    global $kable;
    $breadcrubm_name = isset($kable['optn_breadcrumb_name']) ? $kable['optn_breadcrumb_name'] : esc_html__('Home', 'kable');
    $breadcrubm_delimiter = isset($kable['optn_breadcrumb_delimiter']) ? $kable['optn_breadcrumb_delimiter'] : 'fa fa-angle-right';
    $header_img_repeat = isset($kable['optn_header_img_repeat']) ? $kable['optn_header_img_repeat'] : 'no-repeat';
    $container = isset($kable['main-width-content']) ? $kable['main-width-content'] : 'container';
    $header_img = kable_get_option_data('optn_header_product_img', array('url' => get_template_directory_uri() . '/assets/images/page-title.gif'));

    $top_banner_style = '';
    if (trim($header_img['url']) != '') {
        if ($header_img_repeat == 'no-repeat') {
            $top_banner_style = 'style="background: ' . esc_attr(isset($kable['optn_header_img_bg_color']) ? $kable['optn_header_img_bg_color'] : '#f4f4f4') . ' url(' . esc_url($header_img['url']) . ') ' . esc_attr($header_img_repeat) . ' center center; background-size: cover !important;"';
        } elseif ($header_img_repeat == 'fixed') {
            $top_banner_style = 'style="background: ' . esc_attr(isset($kable['optn_header_img_bg_color']) ? $kable['optn_header_img_bg_color'] : '#f4f4f4') . ' url(' . esc_url($header_img['url']) . ') ' . esc_attr($header_img_repeat) . ' center center; background-size: cover !important; background-attachment: fixed; background-position: 50% 50%"';
        } else {
            $top_banner_style = 'style="background: ' . esc_attr(isset($kable['optn_header_img_bg_color']) ? $kable['optn_header_img_bg_color'] : '#f4f4f4') . ' url(' . esc_url($header_img['url']) . ') ' . esc_attr($header_img_repeat) . ' center center;"';
        }
    }


    //    filtaring breadcrumbs
    return array(
        'delimiter' => '<i class="' . esc_attr($breadcrubm_delimiter) . '" aria-hidden="true"></i>',
        'wrap_before' => '<section ' . $top_banner_style . '><nav class="' . esc_attr($container) . ' woocommerce-breadcrumb">',
        'wrap_after' => '</nav></section>',
        'before' => '',
        'after' => '',
        'home' => esc_attr($breadcrubm_name),
    );
}

if (!function_exists('kable_woo_deal_progress_bar')) {

    /**
     * deal progress bar
     */
    function kable_woo_deal_progress_bar()
    {
        $total_stock_quantity = get_post_meta(get_the_ID(), '_total_stock_quantity', true);
        if (!empty($total_stock_quantity)) {
            $stock_quantity = round($total_stock_quantity);
            $stock_available = ($stock = get_post_meta(get_the_ID(), '_stock', true)) ? round($stock) : 0;
            $stock_sold = ($stock_quantity > $stock_available ? $stock_quantity - $stock_available : 0);
            $percentage = ($stock_sold > 0 ? round($stock_sold / $stock_quantity * 100) : 0);
        } else {
            $stock_sold = ($total_sales = get_post_meta(get_the_ID(), 'total_sales', true)) ? round($total_sales) : 0;
            $stock_available = ($stock = get_post_meta(get_the_ID(), '_stock', true)) ? round($stock) : 0;
            $percentage = ($stock_available > 0 ? round($stock_sold / $stock_available * 100) : 0);
        }

        if ($stock_available > 0) :
            ?>
            <div class="piko-stock mt25">
                <div class="d_flex justify-content-between mb10">
                    <span><?php echo esc_html__('Already Sold:', 'kable'); ?> <span class="f_w5"><?php echo esc_html($stock_sold); ?></span></span>
                    <span><?php echo esc_html__('Available:', 'kable'); ?> <span class="f_w5"><?php echo esc_html($stock_available); ?></span></span>
                </div>
                <div class="progress">
                    <span class="progress-bar" style="<?php echo esc_attr('width:' . $percentage . '%'); ?>"><?php echo esc_html($percentage); ?></span>
                </div>
            </div>
        <?php
        endif;
    }
}

if (!function_exists('kable_get_max_date_sale')) {

    /**
     * Get max date sale variable
     * */
    function kable_get_max_date_sale($product_id)
    {
        $time = 0;
        // Get variations
        $args = array(
            'post_type' => 'product_variation',
            'post_status' => array('private', 'publish'),
            'numberposts' => -1,
            'orderby' => 'menu_order',
            'order' => 'asc',
            'post_parent' => $product_id
        );
        $variations = get_posts($args);
        $variation_ids = array();
        if ($variations) {
            foreach ($variations as $variation) {
                $variation_ids[] = $variation->ID;
            }
        }
        $sale_price_dates_to = false;

        if (!empty($variation_ids)) {
            global $wpdb;
            $sale_price_dates_to = $wpdb->get_var("
                SELECT
                meta_value
                FROM $wpdb->postmeta
                WHERE meta_key = '_sale_price_dates_to' and post_id IN(" . join(',', $variation_ids) . ")
                ORDER BY meta_value DESC
                LIMIT 1
            ");

            if ($sale_price_dates_to != '') {
                return $sale_price_dates_to;
            }
        }

        if (!$sale_price_dates_to) {
            $sale_price_dates_to = get_post_meta($product_id, '_sale_price_dates_to', true);

            if ($sale_price_dates_to == '') {
                $sale_price_dates_to = '0';
            }

            return $sale_price_dates_to;
        }
    }
}
if (!function_exists('kable_related_products_args')) {

    /**
     * Custom item related_products
     * */
    function kable_related_products_args($args)
    {
        $args['posts_per_page'] = 9; // 4 to 9 related product
        return $args;
    }
}
add_filter('woocommerce_output_related_products_args', 'kable_related_products_args');

//tootls bar

if (!function_exists('get')) {

    function get($var)
    {
        return isset($_GET[$var]) ? $_GET[$var] : (isset($_REQUEST[$var]) ? $_REQUEST[$var] : '');
    }
}

if (!function_exists('post')) {

    function post($var)
    {
        return isset($_POST[$var]) ? $_POST[$var] : null;
    }
}

if (!function_exists('cookie')) {

    function cookie($var)
    {
        return isset($_COOKIE[$var]) ? $_COOKIE[$var] : null;
    }
}

if (!function_exists('kable_get_the_content_with_formatting')) {

    function kable_get_the_content_with_formatting()
    {
        $content = get_the_content();
        $content = apply_filters('the_content', $content);
        $content = do_shortcode($content);
        return $content;
    }
}

if (!function_exists('kable_add_formatting')) {

    function kable_add_formatting($content)
    {
        $content = do_shortcode($content);
        return $content;
    }
}


if (!function_exists('kable_get_current_page_url')) {

    function kable_get_current_page_url()
    {
        $current_url = add_query_arg(null, null);
        return esc_url($current_url);
    }
}
if (!function_exists('kable_woocommerce_add_badge_new_in_list')) {

    function kable_woocommerce_add_badge_new_in_list()
    {
        global $post, $kable, $product;
        $days_count = isset($kable['optn_new_product_label']) ? $kable['optn_new_product_label'] : '30';
        $label_text = isset($kable['optn_new_product_label_text']) ? $kable['optn_new_product_label_text'] : esc_html__('New', 'kable');

        if ($product->is_featured()) {
            echo '<span class="product-label featured">' . esc_html__('Hot', 'kable') . '</span>';
        }

        if (get_post_meta(get_the_ID(), '_is_new', true) != 'yes') {
            return;
        }

        $post_date = get_the_time('Y-m-d', $post);
        $post_date_stamp = strtotime($post_date);
        $newness = esc_attr($days_count);
        if ((time() - (60 * 60 * 24 * $newness)) < $post_date_stamp) {
            $class = 'product-label new';
            echo '<span class="' . $class . '">' . esc_attr($label_text) . '</span>';
        }
    }
}

function kable_woocommerce_add_badge_out_of_stock()
{
    global $product, $kable;
    $out_of_stock_label = isset($kable['optn_product_out_of_stock_label']) ? $kable['optn_product_out_of_stock_label'] : esc_html__('Out of stock', 'kable');
    if (empty($out_of_stock_label)) {
        return;
    }
    if (!$product->is_in_stock()) {
        echo '<span class="product-label outofstock">' . esc_attr($out_of_stock_label) . '</span>';
    }
}

if (!function_exists('kable_woocommerce_override_loop_shop_per_page')) {

    function kable_woocommerce_override_loop_shop_per_page($cols)
    {
        $products_per_page = kable_get_option_data('products_per_page', '20,25,35');
        $mode_view = apply_filters('kable_filter_products_mode_view', 'grid');
        if ($mode_view == 'list') {
            $products_per_page = kable_get_option_data('products_per_page_list', '20,25,35');
        }
        $array_per_page = explode(',', $products_per_page);
        $array_per_page = array_map('trim', $array_per_page);
        $per_page = kable_get_option_data('products_per_page_default', 20);
        $per_page = apply_filters('kable_filter_products_per_page', $per_page);
        if ($per_page && in_array($per_page, $array_per_page)) {
            return $per_page;
        }
        return $cols;
    }
}
if (!function_exists('kable_woocommerce_setcookie_default')) {

    function kable_woocommerce_setcookie_default()
    {
        $default_cookie_expire = time() + 3600 * 24 * 30;

        if (!isset($_COOKIE['kable_products_list_per_page'])) {
            setcookie(
                'kable_products_list_per_page',
                kable_get_option_data('products_per_page_list_default', 20),
                $default_cookie_expire,
                COOKIEPATH
            );
        }
        if (!isset($_COOKIE['kable_products_grid_per_page'])) {
            setcookie(
                'kable_products_grid_per_page',
                kable_get_option_data('products_per_page_default', 20),
                $default_cookie_expire,
                COOKIEPATH
            );
        }
        if (!isset($_COOKIE['kable_products_mode_view'])) {
            setcookie(
                'kable_products_mode_view',
                'grid',
                $default_cookie_expire,
                COOKIEPATH
            );
        }

        // check mode_view
        if (in_array(cookie('kable_products_mode_view'), array('list', 'grid'))) {
            add_filter(
                'kable_filter_products_mode_view',
                function ($per_row) {
                    return cookie('kable_products_mode_view');
                },
                99
            );
        }
        if (in_array(get('view'), array('list', 'grid'))) {
            add_filter(
                'kable_filter_products_mode_view',
                function ($mode) {
                    return get('view');
                },
                99
            );
            setcookie(
                'kable_products_mode_view',
                get('view'),
                $default_cookie_expire,
                COOKIEPATH
            );
        }

        // Check per_row
        if (absint(cookie('kable_products_per_row'))) {
            add_filter(
                'kable_filter_products_per_row',
                function ($per_row) {
                    return absint(cookie('kable_products_per_row'));
                },
                99
            );
        }
        if (absint(get('per_row'))) {
            add_filter(
                'kable_filter_products_per_row',
                function ($per_row) {
                    return absint(get('per_row'));
                },
                99
            );
            setcookie(
                'kable_products_per_row',
                absint(get('per_row')),
                $default_cookie_expire,
                COOKIEPATH
            );
        }

        // check per_page
        $mode_view = in_array(cookie('kable_products_mode_view'), array('list', 'grid')) ? cookie('kable_products_mode_view') : 'grid';
        if (in_array(get('view'), array('list', 'grid'))) {
            $mode_view = get('view');
        }

        if ($mode_view == 'list') {
            if (absint(cookie('kable_products_list_per_page'))) {
                add_filter(
                    'kable_filter_products_per_page',
                    function ($per_row) {
                        return absint(cookie('kable_products_list_per_page'));
                    },
                    99
                );
            }
            if (absint(get('per_page'))) {
                add_filter(
                    'kable_filter_products_per_page',
                    function ($per_page) {
                        return absint(get('per_page'));
                    },
                    99
                );
                setcookie(
                    'kable_products_list_per_page',
                    absint(get('per_page')),
                    $default_cookie_expire,
                    COOKIEPATH
                );
            }
        } else {
            if (absint(cookie('kable_products_grid_per_page'))) {
                add_filter(
                    'kable_filter_products_per_page',
                    function ($per_row) {
                        return absint(cookie('kable_products_grid_per_page'));
                    },
                    99
                );
            }
            if (absint(get('per_page'))) {
                add_filter(
                    'kable_filter_products_per_page',
                    function ($per_page) {
                        return absint(get('per_page'));
                    },
                    99
                );
                setcookie(
                    'kable_products_grid_per_page',
                    absint(get('per_page')),
                    $default_cookie_expire,
                    COOKIEPATH
                );
            }
        }

        // check catalog_orderby
        $catalog_orderby_options = apply_filters(
            'woocommerce_catalog_orderby',
            array(
                'menu_order' => esc_html__('Default sorting', 'kable'),
                'popularity' => esc_html__('Sort by popularity', 'kable'),
                'rating' => esc_html__('Sort by average rating', 'kable'),
                'date' => esc_html__('Sort by newness', 'kable'),
                'price' => esc_html__('Sort by price: low to high', 'kable'),
                'price-desc' => esc_html__('Sort by price: high to low', 'kable')
            )
        );
        if (array_key_exists(cookie('woocommerce_default_catalog_orderby'), $catalog_orderby_options)) {
            add_filter(
                'woocommerce_default_catalog_orderby',
                function ($orderby) {
                    return cookie('woocommerce_default_catalog_orderby');
                },
                99
            );
        }
        if (array_key_exists(get('orderby'), $catalog_orderby_options)) {
            add_filter(
                'woocommerce_default_catalog_orderby',
                function ($orderby) {
                    return get('orderby');
                },
                99
            );
            setcookie(
                'woocommerce_default_catalog_orderby',
                get('orderby'),
                $default_cookie_expire,
                COOKIEPATH
            );
        }
    }
}

if (!function_exists('kable_woocommerce_add_toolbar')) {

    function kable_woocommerce_add_toolbar()
    {
        wc_get_template('loop/toolbar.php');
    }
}

if (!function_exists('kable_woocommerce_add_toolbar_position')) {

    function kable_woocommerce_add_toolbar_position()
    {
        $link = kable_get_current_page_url();
        ?>
        <div class="sort-by-wrapper sort-by-order">
            <div class="sort-by-label"><?php esc_attr_e('Position', 'kable') ?></div>
            <div class="sort-by-content">
                <ul>
                    <li<?php if (strtolower(get('order')) == 'asc') echo ' class="active"'; ?>>
                        <a href="<?php echo esc_url(add_query_arg('order', 'asc', $link)) ?>"><?php esc_attr_e('Ascending', 'kable') ?></a>
                        </li>
                        <li<?php if (strtolower(get('order')) == 'desc') echo ' class="active"'; ?>>
                            <a href="<?php echo esc_url(add_query_arg('order', 'desc', $link)) ?>"><?php esc_attr_e('Descending', 'kable') ?></a>
                            </li>
                </ul>
            </div>
        </div>
    <?php
    }
}

if (!function_exists('kable_woocommerce_add_gridlist_toggle_button')) {

    function kable_woocommerce_add_gridlist_toggle_button()
    {
        global $wp;
        $mode_views = array(
            'list' => array(
                esc_html__('List view', 'kable'),
                '<span><i class="icon-list"></i></span>'
            ),
            'grid' => array(
                esc_html__('Grid view', 'kable'),
                '<span><i class="icon-grid"></i></span>'
            )
        );
        $active = apply_filters('kable_filter_products_mode_view', 'grid');
        $params = array();
        if (isset($_GET)) {
            foreach ($_GET as $key => $val) {
                $params[$key] = $val;
            }
        }
        if ('' == get_option('permalink_structure')) {
            $form_action = remove_query_arg(array('per_page', 'page', 'paged'), add_query_arg($wp->query_string, '', home_url($wp->request)));
        } else {
            $form_action = preg_replace('%\/page/[0-9]+%', '', home_url(trailingslashit($wp->request)));
        }
        ?>
        <div class="gridlist-toggle-wrapper">
            <nav class="gridlist_toggle">
                <?php
                if (is_active_sidebar('sidebar-7')) {
                    echo '<a href="javascript:void(0);" class="filter-trigger">Filter<span>+</span></a>';
                }
                foreach ($mode_views as $k => $v) {
                    ?>
                    <a id="<?php echo esc_attr($k); ?>" <?php
                                                        if ($active == $k) {
                                                            echo wp_kses('class="active" href="javascript:;"', array('a' => array('class' => array(), 'href' => array())));
                                                        } else {
                                                            echo wp_kses('href="' . esc_url(add_query_arg('view', $k, $form_action)) . '"', array('a' => array('href' => array())));
                                                        }
                                                        ?> title="<?php echo esc_attr($v[0]) ?>"><?php echo do_shortcode($v[1]) ?></a>
                <?php } ?>
            </nav>
        </div>
    <?php
    }
}

if (!function_exists('kable_woocommerce_add_filter_widgets_on_toolbar')) {

    function kable_woocommerce_add_filter_widgets_on_toolbar()
    {
        ob_start();
        if (is_active_sidebar('sidebar-7')) {
            dynamic_sidebar('sidebar-7');
        }
        $return = ob_get_clean();
        echo do_shortcode($return, true);
    }
}

if (!function_exists('kable_woocommerce_get_catalog_ordering_args')) {

    function kable_woocommerce_get_catalog_ordering_args($args)
    {
        $orderby_value = isset($_GET['orderby']) ? wc_clean($_GET['orderby']) : apply_filters('woocommerce_default_catalog_orderby', get_option('woocommerce_default_catalog_orderby'));
        $orderby_value = explode('-', $orderby_value);
        $orderby = esc_attr($orderby_value[0]);

        if (in_array(strtoupper(get('order')), array('DESC', 'ASC'))) {
            $order = strtoupper(get('order'));
        } else {
            $order = !empty($orderby_value[1]) ? $orderby_value[1] : 'ASC';
        }
        $args['order'] = $order;
        switch ($orderby) {
            case 'popularity':
                add_filter('posts_clauses', 'kable_woocommerce_add_filter_order_by_popularity_post_clauses');
                break;
            case 'rating':
                add_filter('posts_clauses', 'kable_woocommerce_add_filter_order_by_rating_post_clauses');
                break;
        }

        return $args;
    }
}

if (!function_exists('kable_woocommerce_add_filter_order_by_popularity_post_clauses')) {

    function kable_woocommerce_add_filter_order_by_popularity_post_clauses($args)
    {
        global $wpdb;
        $order = in_array(strtoupper(get('order')), array('DESC', 'ASC')) ? strtoupper(get('order')) : 'DESC';
        if (isset($args['orderby'])) {
            if (strpos($args['orderby'], "$wpdb->postmeta.meta_value+0") !== FALSE) {
                $args['orderby'] = "$wpdb->postmeta.meta_value+0 $order, $wpdb->posts.post_date DESC";
            }
        }

        return $args;
    }
}

if (!function_exists('kable_woocommerce_add_filter_order_by_rating_post_clauses')) {

    function kable_woocommerce_add_filter_order_by_rating_post_clauses($args)
    {
        global $wpdb;
        $order = in_array(strtoupper(get('order')), array('DESC', 'ASC')) ? strtoupper(get('order')) : 'DESC';
        if (isset($args['orderby'])) {
            if (strpos($args['orderby'], "average_rating") !== FALSE) {
                $args['orderby'] = "average_rating $order, $wpdb->posts.post_date DESC";
            }
        }
        return $args;
    }
}


if (!function_exists('kable_woocommerce_custom_stock_html')) {

    function kable_woocommerce_custom_stock_html()
    {
        if (is_product()) {
            global $product;
            // Availability
            $availability = $product->get_availability();
            $availability_html = empty($availability['availability']) ? '' : '<p class="stock ' . esc_attr($availability['class']) . '"><span>' . esc_html__('Availability:', 'kable') . '</span> ' . esc_html($availability['availability']) . '</p>';
            echo do_shortcode($availability_html);
        }
    }
}

if (!function_exists('kable_woocommerce_single_super_zoom')) {

    function kable_woocommerce_single_super_zoom()
    {
        $enable = kable_get_option_data('enable_super_zoom', true);
        if (!kable_get_option_data('enable_super_zoom')) {
            add_theme_support('wc-product-gallery-lightbox');
        }
    }
}
if (!function_exists('kable_woocommerce_show_upsell_related_products')) {

    function kable_woocommerce_show_upsell_related_products()
    {

        if (!kable_get_option_data('upsell_products')) {
            remove_action('woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15);
        }
    }
}

function kable_woocommerce_rename_tabs($tabs)
{
    // Rename the  tab
    global $product;
    if ($product->has_attributes() || $product->has_dimensions() || $product->has_weight()) {
        $tabs['additional_information']['title'] = esc_html__('Details', 'kable');
    }

    return $tabs;
}

if (!function_exists('kable_woocommerce_add_filter_product_tab_accessories')) {

    function kable_woocommerce_add_filter_product_tab_accessories($tabs)
    {
        global $product, $post;
        $enable = get_post_meta(get_the_ID(), 'wpa_wcpb', true);
        $accessories = kable_get_option_data('custom_tab_accessories', 'Accessories');
        if ($enable) {
            $tabs['custom_tab_accessories'] = array(
                'title' => $accessories,
                'priority' => 2,
                'callback' => 'kable_woocommerce_add_custom_product_tab_accessories_callback'
            );
        }
        return $tabs;
    }
}

if (!function_exists('kable_woocommerce_add_custom_product_tab_accessories_callback')) {

    function kable_woocommerce_add_custom_product_tab_accessories_callback()
    {
        do_action('kable_wc_product_bundle');
    }
}
if (!function_exists('kable_woocommerce_add_filter_product_tabs')) {

    function kable_woocommerce_add_filter_product_tabs($tabs)
    {
        global $product, $post;
        $custom_html_enable = get_post_meta(get_the_ID(), 'kable_enable_custom_tab_html', true);
        if ($custom_html_enable === '0') {
            $custom_html_enable = kable_get_option_data('custom_tab');
        }
        $custom_tab_heading = get_post_meta(get_the_ID(), 'kable_product_custom_tab_heading', true);
        if (!isset($custom_tab_heading) || $custom_tab_heading == '-1' || $custom_tab_heading == '') {
            $custom_tab_heading = kable_get_option_data('custom_tab_title', esc_html__('Custom Tab', 'kable'));
        }

        if ($custom_html_enable) {
            $tabs['custom_tab'] = array(
                'title' => $custom_tab_heading,
                'priority' => 21,
                'callback' => 'kable_woocommerce_add_custom_product_tab_callback'
            );
        }
        return $tabs;
    }
}

if (!function_exists('kable_woocommerce_add_custom_product_tab_callback')) {

    function kable_woocommerce_add_custom_product_tab_callback()
    {
        $custom_html_tab = get_post_meta(get_the_ID(), 'kable_product_custom_tab_content', true);
        if (!isset($custom_html_tab) || $custom_html_tab == '-1' || $custom_html_tab == '') {
            $custom_html_tab = kable_get_option_data('custom_tab_content');
        }
        echo kable_add_formatting($custom_html_tab);
    }
}
if (!function_exists('kable_woocommerce_add_filter_product_tabs_two')) {

    function kable_woocommerce_add_filter_product_tabs_two($tabs)
    {
        global $product, $post;

        $custom_html_enable = get_post_meta(get_the_ID(), 'kable_enable_custom_tab_html2', true);
        $custom_tab_heading = get_post_meta(get_the_ID(), 'kable_product_custom_tab_heading2', true);

        if ($custom_html_enable) {
            $tabs['custom_tab_two'] = array(
                'title' => $custom_tab_heading,
                'priority' => 22,
                'callback' => 'kable_woocommerce_add_custom_product_tab_callback_two'
            );
        }

        return $tabs;
    }
}
if (!function_exists('kable_woocommerce_add_custom_product_tab_callback_two')) {

    function kable_woocommerce_add_custom_product_tab_callback_two()
    {
        $custom_html_tab = get_post_meta(get_the_ID(), 'kable_product_custom_tab_content2', true);
        echo kable_add_formatting($custom_html_tab);
    }
}

function kable_woocommerce_product_short_description()
{
    global $post;
    if (!$post->post_excerpt) {
        return;
    }
    echo '<p>' . wp_trim_words(get_the_excerpt(), esc_attr(12), ' ... ') . '<p>';
}

if (!function_exists('kable_woocommerce_init_sortable_taxonomies_brand')) {
    add_filter('woocommerce_sortable_taxonomies', 'kable_woocommerce_init_sortable_taxonomies_brand');

    function kable_woocommerce_init_sortable_taxonomies_brand($return)
    {
        global $current_screen;
        $return[] = 'product_brand';
        if (is_object($current_screen) && in_array($current_screen->id, array('edit-product_brand'))) {
            wp_enqueue_media();
        }
        return $return;
    }
}

add_action('init', 'kable_woocommerce_setcookie_default');

add_filter('loop_shop_per_page', 'kable_woocommerce_override_loop_shop_per_page', 20);


add_filter('woocommerce_get_catalog_ordering_args', 'kable_woocommerce_get_catalog_ordering_args');


if (!function_exists('kable_wc_add_widgets_on_shop')) {

    function kable_wc_add_widgets_on_shop()
    {

        $enable_widget = kable_get_option_data('woo_archive_widget_enable', 0);
        $woo_archive_widget = kable_get_option_data('woo_archive_widget', 'sidebar-8');
        ob_start();
        if ($enable_widget == 1 && !is_product() && is_active_sidebar($woo_archive_widget)) { //for shop page
            echo '<div class="woo-archive-widget mb30">';
            dynamic_sidebar($woo_archive_widget);
            echo '</div>';
        }
        $return = ob_get_clean();
        echo do_shortcode($return, true);
    }
}
if (!function_exists('kable_product_cat_class')) {

    //    for product category

    function kable_product_cat_class($classes)
    {
        $products_per_row = kable_get_option_data('optn_woo_products_per_row', '4');

        switch ($products_per_row) {
            case '2':
                $classes[] = 'col-12 col-sm-6';
                break;
            case '3':
                $classes[] = 'col-12 col-sm-6 col-md-4';
                break;
            case '4':
                $classes[] = 'col-12 col-sm-6 col-md-4 col-lg-3';
                break;
            default:
                $classes[] = 'col-12 col-sm-6 col-md-4 col-lg-3 col-xl-20';
        }

        return $classes;
    }

    add_filter('product_cat_class', 'kable_product_cat_class', 50);
}

if (!function_exists('kable_get_new_product_ids')) {

    function kable_get_new_product_ids()
    {

        // Load from browser cache.
        $product_ids = get_transient('kable_woocommerce_new_products');

        // Valid cache found.
        if (false !== $product_ids) {
            return $product_ids;
        }

        $product_ids = array();

        // Get products which are set as new ribbon.
        $meta_query = WC()->query->get_meta_query();
        $meta_query[] = array(
            'key' => '_is_new',
            'value' => 'yes',
        );
        $new_products = new WP_Query(array(
            'posts_per_page' => -1,
            'post_type' => 'product',
            'fields' => 'ids',
            'meta_query' => $meta_query,
        ));

        if ($new_products->have_posts()) {
            $product_ids = array_merge($product_ids, $new_products->posts);
        }

        // Get products after selected days.
        $newness = intval(kable_get_option_data('optn_new_product_label', ''));

        if ($newness > 0) {
            $new_products = new WP_Query(array(
                'posts_per_page' => -1,
                'post_type' => 'product',
                'fields' => 'ids',
                'date_query' => array(
                    'after' => date('Y-m-d', strtotime('-' . $newness . ' days'))
                )
            ));

            if ($new_products->have_posts()) {
                $product_ids = array_merge($product_ids, $new_products->posts);
            }
        }

        set_transient('kable_woocommerce_new_products', $product_ids, DAY_IN_SECONDS);

        return $product_ids;
    }
}

if (!function_exists('kable_get_products_by_filter_group')) {

    function kable_get_products_by_filter_group($query)
    {

        if (is_admin() || empty($_GET['filter_group']) || !is_woocommerce() || !$query->is_main_query()) {
            return;
        }

        switch ($_GET['filter_group']) {
            case 'featured':
                if (version_compare(WC()->version, '3.0.0', '<')) {
                    $meta_query = WC()->query->get_meta_query();
                    $meta_query[] = array(
                        'key' => '_featured',
                        'value' => 'yes',
                    );
                    $query->set('meta_query', $meta_query);
                } else {
                    $tax_query = WC()->query->get_tax_query();
                    $tax_query[] = array(
                        'taxonomy' => 'product_visibility',
                        'field' => 'name',
                        'terms' => 'featured',
                        'operator' => 'IN',
                    );
                    $query->set('tax_query', $tax_query);
                }
                break;

            case 'sale':
                $query->set('post__in', array_merge(array(0), wc_get_product_ids_on_sale()));
                break;

            case 'new':
                $query->set('post__in', array_merge(array(0), kable_get_new_product_ids()));
                break;
        }
    }
}

if (!function_exists('kable_product_filter_data')) {

    //    for data filter

    function kable_product_filter_data($classes)
    {



        $toggle = kable_get_option_data('products_toggle', 1);
        $display = (kable_get_option_data('products_toggle_taxonomy_keep') && is_product_taxonomy()) || is_shop();

        if ($toggle) {
            $type = kable_get_option_data('products_toggle_type');
            echo '<ul class="piko-filter tabs ul-no">';

            printf(
                '<li class="active"><a href="%s" data-filter="*" >%s</a></li>',
                esc_url(remove_query_arg(array('filter_group'))),
                esc_html__('All Products', 'kable')
            );

            if ('cats' == $type && $display) {
                $args = array(
                    'taxonomy' => 'product_cat',
                    'orderby' => 'count',
                    'order' => 'DESC',
                    'include' => kable_get_option_data('products_toggle_cats'),
                );

                $categories = get_terms($args);

                if ($categories && !is_wp_error($categories)) {
                    foreach ($categories as $category) {
                        printf(
                            '<li><a href="%s" data-filter=".product_cat-%s">%s</a></li>',
                            esc_url(get_term_link($category)),
                            esc_attr($category->slug),
                            esc_html($category->name)
                        );
                    }
                }
            } elseif ('group' == $type || !$display) {
                $groups = kable_get_option_data('products_toggle_group', array());
                $base_url = '';

                if ($groups == NULL) {
                    return;
                }

                if (is_shop()) {
                    $base_url = wc_get_page_permalink('shop');
                } elseif (is_product_taxonomy()) {
                    $term = get_queried_object();
                    $base_url = get_term_link($term);
                }
                if (in_array('featured', $groups)) {
                    printf(
                        '<li class="%s"><a href="%s" data-filter=".featured">%s</a></li>',
                        isset($_GET['filter_group']) && 'featured' == $_GET['filter_group'] ? 'active' : '',
                        esc_url(add_query_arg(array('filter_group' => 'featured'), $base_url)),
                        esc_html__('Hot Products', 'kable')
                    );
                }

                if (in_array('new', $groups)) {
                    printf(
                        '<li class="%s"><a href="%s" data-filter=".new">%s</a></li>',
                        isset($_GET['filter_group']) && 'new' == $_GET['filter_group'] ? 'active' : '',
                        esc_url(add_query_arg(array('filter_group' => 'new'), $base_url)),
                        esc_html__('New Products', 'kable')
                    );
                }

                if (in_array('sale', $groups)) {
                    printf(
                        '<li class="%s"><a href="%s" data-filter=".sale">%s</a></li>',
                        isset($_GET['filter_group']) && 'sale' == $_GET['filter_group'] ? 'active' : '',
                        esc_url(add_query_arg(array('filter_group' => 'sale'), $base_url)),
                        esc_html__('Sales Products', 'kable')
                    );
                }
            }

            echo '</ul>';
        }
    }
}


//category header image
if (!function_exists('kable_wc_show_cat_page_title')) {

    function kable_wc_show_cat_page_title()
    {

        if (apply_filters('woocommerce_show_page_title', true) && !is_shop()) :
            ?>
            <header class="woocommerce-products-header pr">
                <h1 class="woocommerce-products-header__title page-title lh_2 f_s25" data-title="<?php woocommerce_page_title(); ?>"><?php woocommerce_page_title(); ?></h1>
            </header>
        <?php
        endif;
    }
}


if (!function_exists('kable_wc_get_header_image_url')) {

    function kable_wc_get_header_image_url($cat_ID = false)
    {
        if ($cat_ID == false && is_product_category()) {
            global $wp_query;

            // get the query object
            $cat = $wp_query->get_queried_object();

            // get the thumbnail id user the term_id
            $cat_ID = $cat->term_id;
        }

        $thumbnail_id = get_term_meta($cat_ID, 'header_id', true);

        // get the image URL
        return wp_get_attachment_url($thumbnail_id);
    }
}
if (!function_exists('kable_wc_get_header_image_html_start')) {

    function kable_wc_get_header_image_html_start()
    {
        if (!function_exists('pikoworks_wc_get_header_image_url'))
            return;
        $src = pikoworks_wc_get_header_image_url();
        if (empty($src))
            return;
        echo '<div class="pikowc_header_image pr" style="background-image:url(' . esc_url($src) . ')">';
    }
}
if (!function_exists('kable_wc_get_header_image_html_end')) {

    function kable_wc_get_header_image_html_end()
    {
        if (!function_exists('pikoworks_wc_get_header_image_url'))
            return;
        $src = pikoworks_wc_get_header_image_url();
        if (empty($src))
            return;
        echo '</div>';
    }
}

if (!function_exists('kable_wc_before_shop_loop_item_title_before')) {

    function kable_wc_before_shop_loop_item_title_before()
    {
        echo '<div class="product-top p_r o_h">';
    }
}
if (!function_exists('kable_wc_before_shop_loop_item_title_after')) {

    function kable_wc_before_shop_loop_item_title_after()
    {
        echo '</div>';
    }
}
//single page

if (!function_exists('kable_wc_single_product_summary_before')) {

    function kable_wc_single_product_summary_before()
    {
        echo '<div class="btn-details-action">';
    }
}
if (!function_exists('kable_wc_single_product_summary_after')) {

    function kable_wc_single_product_summary_after()
    {
        echo '</div>';
    }
}


//woocommerce bidding field
add_filter('woocommerce_checkout_fields', 'kable_custom_override_checkout_fields');

// Our hooked in function - $fields is passed via the filter!
function kable_custom_override_checkout_fields($fields)
{

    $fields['billing']['billing_first_name'] = array(
        'label' => __('First name', 'woocommerce'),
        'placeholder' => __('First name', 'woocommerce'),
        'required' => true,
        'class' => array('form-row-first', 'helf-1'),
        'autocomplete' => 'given-name',
    );
    $fields['billing']['billing_last_name'] = array(
        'label' => __('Last name', 'woocommerce'),
        'placeholder' => __('Last name', 'woocommerce'),
        'required' => true,
        'class' => array('form-row-last', 'helf-2'),
        'autocomplete' => 'family-name',
    );
    $fields['billing']['billing_company'] = array(
        'label' => __('Company name', 'woocommerce'),
        'placeholder' => __('Company name', 'woocommerce'),
        'class' => array('form-row-wide'),
        'autocomplete' => 'organization',
        'required' => 'required' === get_option('woocommerce_checkout_company_field', 'optional'),
    );
    $fields['billing']['billing_city'] = array(
        'label' => __('Town / City', 'woocommerce'),
        'placeholder' => __('Town / City', 'woocommerce'),
        'required' => true,
        'class' => array('form-row-wide', 'address-field', 'helf-1'),
        'autocomplete' => 'address-level2',
    );
    $fields['billing']['billing_state'] = array(
        'type' => 'state',
        'label' => __('State / County', 'woocommerce'),
        'placeholder' => __('State / County', 'woocommerce'),
        // 'required' => true,
        'class' => array('form-row-wide', 'address-field', 'helf-2'),
        'validate' => array('state'),
        'autocomplete' => 'address-level1',
    );
    $fields['billing']['billing_postcode'] = array(
        'label' => __('Postcode / ZIP', 'woocommerce'),
        'placeholder' => __('Postcode / ZIP', 'woocommerce'),
        'required' => true,
        'class' => array('form-row-wide', 'address-field'),
        'validate' => array('postcode'),
        'autocomplete' => 'postal-code',
    );
    $fields['billing']['billing_phone'] = array(
        'label' => __('Phone', 'woocommerce'),
        'placeholder' => __('Phone', 'woocommerce'),
        'required' => 'required' === get_option('woocommerce_checkout_phone_field', 'required'),
        'type' => 'tel',
        'class' => array('form-row-wide'),
        'validate' => array('phone'),
        'autocomplete' => 'tel',
    );
    $fields['billing']['billing_email'] = array(
        'label' => __('Email address', 'woocommerce'),
        'placeholder' => __('Email address', 'woocommerce'),
        'required' => true,
        'type' => 'email',
        'class' => array('form-row-wide'),
        'validate' => array('email'),
        'autocomplete' => 'no' === get_option('woocommerce_registration_generate_username') ? 'email' : 'email username',
    );


    //    shipping
    $fields['shipping']['shipping_first_name'] = array(
        'label' => __('First name', 'woocommerce'),
        'placeholder' => __('First name', 'woocommerce'),
        'required' => true,
        'class' => array('form-row-first', 'helf-1'),
        'autocomplete' => 'given-name',
    );
    $fields['shipping']['shipping_last_name'] = array(
        'label' => __('Last name', 'woocommerce'),
        'placeholder' => __('Last name', 'woocommerce'),
        'required' => true,
        'class' => array('form-row-last', 'helf-2'),
        'autocomplete' => 'family-name',
    );
    $fields['shipping']['shipping_company'] = array(
        'label' => __('Company name', 'woocommerce'),
        'placeholder' => __('Company name', 'woocommerce'),
        'class' => array('form-row-wide'),
        'autocomplete' => 'organization',
        'required' => 'required' === get_option('woocommerce_checkout_company_field', 'optional'),
    );
    $fields['shipping']['shipping_city'] = array(
        'label' => __('Town / City', 'woocommerce'),
        'placeholder' => __('Town / City', 'woocommerce'),
        'required' => true,
        'class' => array('form-row-wide', 'address-field', 'helf-1'),
        'autocomplete' => 'address-level2',
    );
    $fields['shipping']['shipping_state'] = array(
        'type' => 'state',
        'label' => __('State / County', 'woocommerce'),
        'placeholder' => __('State / County', 'woocommerce'),
        // 'required' => true,
        'class' => array('form-row-wide', 'address-field ', 'helf-2'),
        'validate' => array('state'),
        'autocomplete' => 'address-level1',
    );
    $fields['shipping']['shipping_postcode'] = array(
        'label' => __('Postcode / ZIP', 'woocommerce'),
        'placeholder' => __('Postcode / ZIP', 'woocommerce'),
        'required' => true,
        'class' => array('form-row-wide', 'address-field'),
        'validate' => array('postcode'),
        'autocomplete' => 'postal-code',
    );

    return $fields;
}

/**
 * Class Kable_WC_Product_Settings
 *
 * Add for fields into a product data meta box
 */
class Kable_WC_Product_Settings
{

    /**
     * Initialize
     */
    public static function init()
    {
        add_action('woocommerce_product_options_advanced', array(__CLASS__, 'add_advanced_options'));

        add_action('save_post', array(__CLASS__, 'save_product_data'));
    }

    /**
     * Add more fields to "Advanced" product data tab
     */
    public static function add_advanced_options()
    {
        woocommerce_wp_checkbox(array(
            'id' => '_is_new',
            'label' => esc_html__('New product?', 'kable'),
            'description' => esc_html__('Enable this product as a new product. This product added A "New" badge.', 'kable'),
        ));
    }

    /**
     * Save product data
     *
     * @param int $post_id
     */
    public static function save_product_data($post_id)
    {
        if ('product' !== get_post_type($post_id)) {
            return;
        }

        if (!isset($_POST['_is_new'])) {
            delete_post_meta($post_id, '_is_new');
        } else {
            update_post_meta($post_id, '_is_new', 'yes');
        }
    }
}

if (is_admin()) {
    Kable_WC_Product_Settings::init();
}
