<?php
/**
* @themepiko
* @tabs portfolio
*/
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}
if ( ! in_array( 'js_composer/js_composer.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
    return;
}
add_action('vc_before_init', 'pikoworks_tabs_portfolio');

function pikoworks_tabs_portfolio()
{
    $p_category = 'portfolio-category';
    if (defined('PIKO_PORTFOLIO_CATEGORY_TAXONOMY') && taxonomy_exists(PIKO_PORTFOLIO_CATEGORY_TAXONOMY)) {
        $p_category = PIKO_PORTFOLIO_CATEGORY_TAXONOMY;
    }

    $params = array(
        "name" => esc_html__("Portfolio Tabs", 'pikoworks_core'),
        "base" => "tabs_portfolio",
        "category" => esc_html__('Pikoworks', 'pikoworks_core'),
        "icon" => get_template_directory_uri() . "/assets/images/logo/favicon.png",
        "description" => esc_html__("Tabs Portfolio categories", 'pikoworks_core'),
        "as_parent" => array('only' => 'tab_portfolio'), // Use only|except attributes to limit child shortcodes (separate multiple values with comma)
        "content_element" => true,
        "show_settings_on_create" => true,
        "params" => array_merge(array(
            array(
                'type' => 'dropdown',
                'heading' => esc_html__('Tabs Panel Alignment', 'pikoworks_core'),
                'param_name' => 'tabs_panels_align',
                'value' => array(
                    esc_html__('Center', 'pikoworks_core') => 'center',
                    esc_html__('Left', 'pikoworks_core') => 'start',
                    esc_html__('Right', 'pikoworks_core') => 'end',
                ),
            ),
            array(
                "type" => "textfield",
                "heading" => esc_html__("Tab filter All", 'pikoworks_core'),
                "param_name" => "all",
                "std" => "All Portfolio",
                'description' => esc_html__('If Empty nothing show All filter', 'pikoworks_core'),
            ),
            array(
                'type' => 'dropdown',
                'heading' => esc_html__('Tabs layouts', 'pikoworks_core'),
                'param_name' => 'tabs_type',
                'value' => array(
                    esc_html__('Grid', 'pikoworks_custom_post') => 'grid',
                    esc_html__('Masonry One', 'pikoworks_custom_post') => 'masonry',
                    esc_html__('Masonry Two', 'pikoworks_custom_post') => 'masonry-style02',
                    esc_html__('Masonry Three', 'pikoworks_custom_post') => 'masonry-two',
                    esc_html__('Masonry Classic', 'pikoworks_custom_post') => 'masonry-classic',
                ),
                'std' => 'grid',
            ),
            array(
                "type" => "dropdown",
                "heading" => esc_html__('Distance between 2 item', 'pikoworks_core'),
                "param_name" => "no_gutters",
                'value' => array(
                    esc_html__('30px', 'pikoworks_custom_post') => 'default',
                    esc_html__('0px', 'pikoworks_custom_post') => 'no-gutters',
                    esc_html__('15px', 'pikoworks_custom_post') => 'gutters7',
                    esc_html__('50px', 'pikoworks_custom_post') => 'gutters8',
                    esc_html__('56px', 'pikoworks_custom_post') => 'gutters56',
                    esc_html__('130px', 'pikoworks_custom_post') => 'gutters130'
                ),
                'std' => 'default',
            ),
            array(
                "type" => "pikoworks_number",
                "heading" => esc_html__("Portfolio Load", 'pikoworks_core'),
                "param_name" => "per_page",
                'std' => 6,
                'description' => esc_html__('NB:-1 is available product load in this section', 'pikoworks_core')
            ),
            array(
                "type" => "textfield",
                "heading" => esc_html__("Extra class name", "pikoworks_core"),
                "param_name" => "el_class",
                "description" => esc_html__("If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "pikoworks_core"),
                'admin_label' => false,
            ),
            array(
                'type' => 'css_editor',
                'heading' => esc_html__('Css', 'pikoworks_core'),
                'param_name' => 'css',
                'group' => esc_html__('Design options', 'pikoworks_core'),
                'admin_label' => false,
            ),
        ), pikoworks_get_slider_params_enable()),
        "js_view" => 'VcColumnView'
    );

    vc_map($params);
    vc_map(array(
        "name" => esc_html__("Portfolio Tab", 'pikoworks_core'),
        "base" => "tab_portfolio",
        "content_element" => true,
        "as_child" => array('only' => 'tabs_portfolio'),
        "params" => array(
            array(
                "type" => "textfield",
                "heading" => esc_html__("Tab Title", 'pikoworks_core'),
                "param_name" => "header",
                "std" => "Tab Name",
                'description' => esc_html__('If Empty nothing show title', 'pikoworks_core'),
            ),
            array(
                "type" => "dropdown",
                "heading" => esc_html__("Section Type", 'pikoworks_core'),
                "param_name" => "section_type",
                "admin_label" => true,
                'std' => 'category',
                'value' => array(
                    esc_html__('Category', 'pikoworks_core') => 'category',
                    esc_html__('By Ids', 'pikoworks_core') => 'by-ids'
                    
                ),
            ),
            array(
                "type" => "pikoworks_taxonomy",
                "taxonomy" => PIKO_PORTFOLIO_CATEGORY_TAXONOMY,
                "heading" => esc_html__("Display Portfolio certain category", 'pikoworks_core'),
                "param_name" => "section_cate",
                "value" => '',
                'parent' => '',
                'multiple' => true,
                'hide_empty' => false,
                'placeholder' => esc_html__('Choose categoy', 'pikoworks_core'),
                "dependency" => array("element" => "section_type", "value" => array('category')),
            ),
            array(
                "type" => "dropdown",
                "heading" => esc_html__("Order by", 'pikoworks_core'),
                "param_name" => "orderby",
                "value" => array(
                    esc_html__('None', 'pikoworks_core') => 'none',
                    esc_html__('ID', 'pikoworks_core') => 'ID',
                    esc_html__('Author', 'pikoworks_core') => 'author',
                    esc_html__('Name', 'pikoworks_core') => 'name',
                    esc_html__('Date', 'pikoworks_core') => 'date',
                    esc_html__('Modified', 'pikoworks_core') => 'modified',
                    esc_html__('Rand', 'pikoworks_core') => 'rand',
                ),
                'std' => 'date',
                "description" => esc_html__("Select how to sort retrieved posts.", 'pikoworks_core'),
                "dependency" => array("element" => "section_type", "value" => array('category')),
            ),
            array(
                "type" => "textfield",
                "heading" => esc_html__("Ids", 'pikoworks_core'),
                "param_name" => "ids",
                "admin_label" => true,
                "description" => esc_html__("Get product by list ids.( Input IDs which separated by a comma ',' )", 'pikoworks_core'),
                "dependency" => array("element" => "section_type", "value" => array('by-ids')),
            ),
            array(
                "type" => "dropdown",
                "heading" => esc_html__("Order", 'pikoworks_core'),
                "param_name" => "order",
                "value" => array(
                    esc_html__('ASC', 'pikoworks_core') => 'ASC',
                    esc_html__('DESC', 'pikoworks_core') => 'DESC'
                ),
                'std' => 'DESC',
                "description" => esc_html__("Designates the ascending or descending order.", 'pikoworks_core'),
                "dependency" => array("element" => "section_type", "value" => array('category')),
            ),
        )
    ));
}

class WPBakeryShortCode_Tabs_Portfolio extends WPBakeryShortCodesContainer
{

    protected function content($atts, $content = null)
    {

        $atts = function_exists('vc_map_get_attributes') ? vc_map_get_attributes('tabs_portfolio', $atts) : $atts;
        extract(shortcode_atts(array(
            'tabs_type' => 'grid',
            'per_page' => '6',
            'category' => 0,
            'term_link' => '', //no
            'tabs_panels_align' => '',
            'all' => '',
            'no_gutters' => 'gutters5',

            //Carousel
            'use_responsive' => '1',
            'is_slider' => '',
            'slides_scroll' => "",
            'autoplay' => "false",
            'loop' => "false",
            'navigation' => "true",
            'navigation_btn' => '',
            'btn_hover_show' => '',
            'btn_light' => '',
            'dots' => "false",
            'margin' => '',
            'items_very_large_device' => 6,
            'items_large_device' => 4,
            'items_mobile_device' => 2,
            'el_class' => '',
            'css' => ''
        ), $atts));
        $column = $per_page; // for masonry column

        $item_cols = '';
        if ($use_responsive == '1') {
            $item_cols = 'columns-' . $items_very_large_device;
        }
        $column = $items_very_large_device;

        $css_class = ' s-item-' . $use_responsive . ' ' . $item_cols  . ' ' . $el_class;
        if (function_exists('vc_shortcode_custom_css_class')) :
            $css_class .= ' ' . apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
        endif;

        $tabs = pikoworks_core_get_all_attributes('tab_portfolio', $content);

        if (count($tabs) > 0) :
            $id = uniqid($category);

            $id_tab_fitler = '.tab-' . $id . '-' . 0;

            $col_lg = round(12 / $items_large_device);
            if ($items_large_device == '4') {
                $col_md = ($col_lg + 1);
            } elseif ($items_large_device == '3') {
                $col_md = ($col_lg + 2);
            } elseif ($items_large_device == '6') {
                $col_md = ($col_lg + 1);
            } else {
                $col_md = $col_lg;
            }

            $large_device = round(12 / $items_very_large_device);
            if ($items_very_large_device == '5') {
                $large_device = '20';
            }
            if (!pikoworks_is_mobile()) {
                $col_class[] = 'col-xl-' . $large_device;
                $col_class[] = 'col-lg-' . $col_lg;
                $col_class[] = 'col-md-' . $col_md;
                $col_class[] = 'col-sm-6';
                $col_class = esc_attr(implode(' ', $col_class));
            }

            //    for mobile 2 cloumn
            $row_mobile = '';
            if ($items_mobile_device == '2') {
                $row_mobile = 'mobile';
            }


            $no_gap = $no_gutters;
            if ($no_gutters == 'default') {
                $no_gap = 'sip';
            }

            $slide_before = $slide_after = $slide_class = $data_masonry = $data_slick = $data_filter_dot = $tabs_slide = $slides_scroll_lg = '';

            if ($slides_scroll != 1 && !pikoworks_is_mobile()) {
                $slides_scroll_lg = ',"slidesToScroll": ' . esc_attr($items_large_device);
            }

            if ($is_slider == 'yes' || pikoworks_is_mobile() && !pikoworks_is_tablet()) {
                $col_class = '';
                $tabs_slide = 'fix-p-hover';
                $data_class = 'piko-tab-slide hsc ' . $no_gap . ' ' . $row_mobile;
                $slide_class = 'piko-carousel ' . ' ' . $navigation_btn . ' ' . $btn_light . ' ' . $btn_hover_show . ' ' . $margin;

                $res_large = $use_responsive ? '"slidesToShow":' . esc_attr($items_very_large_device) . ', "slidesToScroll": ' . esc_attr($slides_scroll) . ',' : '';
                $res_media = $use_responsive ? '"responsive":[{"breakpoint": 1200,"settings":{"slidesToShow":' . esc_attr($items_very_large_device) . '}},{"breakpoint": 992,"settings":{"slidesToShow":' . esc_attr($items_large_device . $slides_scroll_lg) . '}},{"breakpoint": 768,"settings":{"slidesToShow": 2,"slidesToScroll": 1}},{"breakpoint": 576,"settings":{"slidesToShow":  ' . esc_attr($items_mobile_device) . ', "slidesToScroll": ' . esc_attr($items_mobile_device) . '}}]' : '';

                $data_slick = '{' . $res_large . '"arrows":' . esc_attr($navigation) . ',"dots":' . esc_attr($dots) . ',"infinite":' . esc_attr($loop) . ',"autoplay":' . esc_attr($autoplay) . ',' . $res_media . '}';

                if (pikoworks_is_mobile() && !pikoworks_is_tablet()) {
                    $data_slick = '{' . $res_large . '"arrows":false,"dots":true,"infinite":' . esc_attr($loop) . ',"autoplay":' . esc_attr($autoplay) . ',' . $res_media . '}';
                }

                $slide_before = "<div class='" . esc_attr($slide_class) . "' data-slick='" . $data_slick . "'>";
                $slide_after = '</div>';
            } else {
                $data_class = 'piko-masonry row ' . $no_gap . ' ' . $row_mobile;
                $data_filter_dot = '.';
                $data_masonry = 'data-selector=".portfolio-single" data-layoutMode="fitRows" data-filter="' . esc_attr($id_tab_fitler) . '"';
            }

            if (file_exists(PIKOWORKS_CUSTOM_POST_CORE . 'post-type/portfolio/templates/vc_generate_tab.php')) {
                ob_start();
                @include(PIKOWORKS_CUSTOM_POST_CORE . 'post-type/portfolio/templates/vc_generate_tab.php');
                return ob_get_clean();
            }
        endif;
    }
}

function pikoworks_core_generate_tabs_panel($id, $tabs = array(), $data_filter_dot)
{
    foreach ($tabs as $i => $tab) : $class = "";

    extract(shortcode_atts(array(
        'category' => '',
        'header' => 'title',
        'ids' => '',
    ), $tab));

    if ($i == 0) : $class .= ' active';
    endif;

    ?>
    <li>
        <a class="db <?php echo esc_attr($class) ?>" data-filter="<?php echo esc_attr($data_filter_dot . 'tab-' . $id . '-' . $i) ?>" href="javascript:void(0);">
            <?php echo  esc_html($header); ?>
        </a>
    </li>
    <?php
    endforeach;
}

function pikoworks_core_tab_part_portfolio($portfolio, $id, $class = "", $col_class, $slide_before, $slide_after,  $tabs_type, $column) {
            echo balanceTags($slide_before);
            $post_count = 0;
            if ($portfolio->have_posts()) :
                ?>
        <?php
        while ($portfolio->have_posts()) : $portfolio->the_post();
            $post_count++;
            $index++; ?>
            <li <?php post_class($col_class . ' ' . $id); ?> data-slick-tab="<?php esc_attr_e($id); ?>">
            <?php  include(PIKOWORKS_CUSTOM_POST_CORE . 'post-type/portfolio/templates/loop/' . esc_attr($tabs_type) . '-item.php'); ?>
            </li>
        <?php endwhile; // end of the loop. 
    endif;
    wp_reset_query();
    wp_reset_postdata();
    echo balanceTags($slide_after);
}
/**
 * Execute query to get  product
 *
 * @param $tab array all the setting of section tab
 * @param $term int term_id unique tab
 * @param $meta_query array default empty array
 * @param $per_page int default 5
 * @param $atts array shortcode setting default empty array
 * @return $products array
 * */
function pikoworks_single_tab_portfolio($tab, $term, $meta_query = array(), $per_page = 6, $atts = array()) {
    $newargs = array(
        'post_type' => PIKO_PORTFOLIO_POST_TYPE,
        'post_status' => 'publish',
        'ignore_sticky_posts' => 1,
        'posts_per_page' => esc_attr($per_page),
        'meta_query' => $meta_query,
        'suppress_filter' => true
    );
    if ($term) {
        $newargs ['tax_query'] = array(
            array(
                'taxonomy' => PIKO_PORTFOLIO_CATEGORY_TAXONOMY,
                'field' => 'slug',
                'terms' => $term,
                'operator' => 'IN'
            )
        );
    }
    extract(shortcode_atts(array(
        'header' => 'Tab Name',
        'section_type' => 'category',
        'section_cate' => '',
        'orderby' => 'date',
        'order' => 'DESC',
        'ids' => ''
                    ), $tab));

    if ($section_type == 'category') {
        $chil_term = get_term($section_cate, 'product_cat');

        if ($section_cate) {
            $newargs['tax_query'] = array(
                array(
                    'taxonomy' => PIKO_PORTFOLIO_CATEGORY_TAXONOMY,
                    'field' => 'slug',
                    'terms' => explode(",", $section_cate)
                ),
            );
        }
    } elseif ($section_type == 'by-ids' && $ids) {
        $newargs['post__in'] = explode(',', $ids);
        $newargs['orderby'] = 'ID';
    }
    $portfolio = new WP_Query(apply_filters('portfolio_shortcode_products_query', $newargs, $atts));
    
    return $portfolio;
}